@@ -21,8 +21,8 @@ _columns = {
     "h": ["High"],
     "l": ["Low"],
     "c": ["Close"],
-    "oh2": ["Open", "High"],
-    "olc3": ["Open", "Low", "Close"],
+    "hl2": ["High", "Low"],
+    "hlc3": ["High", "Low", "Close"],
     "ohlc4": ["Open", "High", "Low", "Close"],
 }
 
@@ -48,7 +48,8 @@ class Price:
 
         indicator = Indicator(
             name="price_{}".format(price_source),
-            serie=(self._candles_dataframe[_columns[price_source]]).mean(axis=1),
+            serie=(self._candles_dataframe[_columns[price_source]]).mean(
+                axis=1),
         )
         if create_indicator_column:
             self._candles_dataframe.loc[:, indicator.name] = indicator.serie
