@@ -1,35 +1,42 @@
-seconds_in = {
-    "1m": 60,
-    "3m": 180,
-    "5m": 300,
-    "15m": 900,
-    "30m": 1800,
-    "1h": 3600,
-    "2h": 7200,
-    "4h": 14400,
-    "6h": 21600,
-    "12h": 43200,
-    "1d": 86400,
-    "1w": 604800,
-}
+class TimeFrames:
+    seconds_dict = {
+        "1m": 60,
+        "3m": 180,
+        "5m": 300,
+        "15m": 900,
+        "30m": 1800,
+        "1h": 3600,
+        "2h": 7200,
+        "4h": 14400,
+        "6h": 21600,
+        "12h": 43200,
+        "1d": 86400,
+        "1w": 604800,
+    }
+
+    def __init__(self):
+        pass
+
+    def seconds_in(self, time_frame):
+        return self.seconds_dict[time_frame]
 
 
-class GeneralFormat:
-    def __init__(self, fmt: str, unit: str):
-        self.fmt = fmt
-        self.unit = unit
-
-
-class CandleStickFormat:
-    info = ["Open_time", "Open", "High", "Low", "Close", "Volume"]  # , "Close_time"]
-    time_ = "datetime_string"
+klines_desired_info = [
+    "Open_time",
+    "Open",
+    "High",
+    "Low",
+    "Close",
+    "Volume",
+]  # , "Close_time"]
 
 
 # TODO: API key and secret from get os.environment ou default = None
 class Binance_:
     api_key = None
     api_secret = None
-    CandleTime = GeneralFormat(fmt="timestamp", unit="milliseconds")
+    DateTimeFmt = 'timestamp'
+    DateTimeUnit = 'milliseconds'
     _base_endpoint = "https://api.binance.com/api/v3/"
     _ping_endpoint = _base_endpoint + "ping"
     _time_endpoint = _base_endpoint + "time"
